@@ -23,6 +23,11 @@ sub base :Chained('/') :PathPart('') :CaptureArgs(0) {
   $self->push_viewport(SiteLayout,
     title => 'ComponentUI test title',
     static_base_uri => "${\$c->uri_for('/static')}",
+    meta_info => {
+      http_header => {
+        'Content-Type' => 'text/html;charset=utf-8',
+      },
+    },
   );
 }
 
@@ -31,6 +36,10 @@ sub root :Chained('base') :PathPart('') :Args(0) {
   $self->push_viewport(ViewPort, layout => 'index');
 }
 
+sub bye :Chained('base') :PathPart('bye') :Args(0) {
+  exit;
+}
+
 sub static :Chained('base') :PathPart('static') :Args {
   my ($self, $c, @args) = @_;
   return if $c->stash->{window}->view->serve_static_file($c, \@args);
