@@ -5,11 +5,7 @@ use Reaction::Class;
 use namespace::clean -except => [ qw(meta) ];
 extends 'Reaction::Meta::Attribute';
 
-
-#i feel like something should happen here, but i aint got nothin.
-sub new { shift->SUPER::new(@_); }; # work around immutable
-
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable(inline_constructor => 0);
 
 
 1;
